# Contributing to Brew Day

As an open source project, Brew Day welcomes contributions of many forms.

Examples of contributions include:

* Code patches
* Documentation improvements
* Bug reports and patch reviews

## Contribution guidelines

- Please open a GitHub ticket to explain what you would like to improve/change.
- Pull requests should include test coverage for all new lines of code.
